@@ -1,9 +1,7 @@
-package Class::Easy::Distribution;
+package Project::Easy::Distribution;
 
 # $Id: Distribution.pm,v 1.1 2009/02/09 15:53:21 apla Exp $
 
-use strict;
-
-use warnings;
+use Class::Easy;
 
 1;
\ No newline at end of file
